==> volsite_postgres_common-0.1.44.tar.gz: volsite_postgres_common-0.1.44/src/volsite_postgres_common/db/CFn.py <==
from typing import Final


# ====== CFn: Common Custom Function ======
class CFn:
    array_sort: Final[str] = 'array_sort'
    array_sort_unique: Final[str] = 'array_sort_unique'

    bigint_2_id: Final[str] = 'bigint_2_id'
    bigint_array_2_id_array: Final[str] = 'bigint_array_2_id_array'

    count_jsonb_keys: Final[str] = 'count_jsonb_keys'

    http_status_data: Final[str] = 'http_status_data'
    http_status_error: Final[str] = 'http_status_error'
    http_status_error_code_only: Final[str] = 'http_status_error_code_only'

    id_2_bigint: Final[str] = 'id_2_bigint'
    id_2_int: Final[str] = 'id_2_int'
    if_null_2_empty_bigint_array: Final[str] = 'if_null_2_empty_bigint_array'
    int_2_id: Final[str] = 'int_2_id'
    is_null: Final[str] = 'is_null'

    jsonb_add_key_value_elements: Final[str] = 'jsonb_add_key_value_elements'
    jsonb_array_2_bigint_array: Final[str] = 'jsonb_array_2_bigint_array'
    jsonb_array_2_int_array: Final[str] = 'jsonb_array_2_int_array'
    jsonb_2_jsonb_array: Final[str] = 'jsonb_2_jsonb_array'
    jsonb_array_2_smallint_array: Final[str] = 'jsonb_array_2_smallint_array'
    jsonb_array_2_text_array: Final[str] = 'jsonb_array_2_text_array'
    jsonb_array_2_uuid_array: Final[str] = 'jsonb_array_2_uuid_array'
    jsonb_remove_key: Final[str] = 'jsonb_remove_key'

    jsonb_uuid_array_2_uuid_array: Final[str] = 'jsonb_uuid_array_2_uuid_array'
    jsonb_id_array_2_bigint_array: Final[str] = 'jsonb_id_array_2_bigint_array'
    jsonb_id_array_2_int_array: Final[str] = 'jsonb_id_array_2_int_array'

==> volsite_postgres_common-0.1.49.tar.gz: volsite_postgres_common-0.1.49/src/volsite_postgres_common/db/CFn.py <==
from typing import Final


# ====== CFn: Common Custom Function ======
class CFn:
    array_sort: Final[str] = 'array_sort'
    array_sort_unique: Final[str] = 'array_sort_unique'

    bigint_2_id: Final[str] = 'bigint_2_id'
    bigint_array_2_id_array: Final[str] = 'bigint_array_2_id_array'

    count_jsonb_keys: Final[str] = 'count_jsonb_keys'

    http_status_data: Final[str] = 'http_status_data'
    http_status_error: Final[str] = 'http_status_error'
    http_status_error_code_only: Final[str] = 'http_status_error_code_only'

    id_2_bigint: Final[str] = 'id_2_bigint'
    id_2_int: Final[str] = 'id_2_int'
    if_null_2_empty_bigint_array: Final[str] = 'if_null_2_empty_bigint_array'
    if_null_2_empty_uuid_array: Final[str] = 'if_null_2_empty_uuid_array'
    int_2_id: Final[str] = 'int_2_id'
    is_null: Final[str] = 'is_null'

    jsonb_add_key_value_elements: Final[str] = 'jsonb_add_key_value_elements'
    jsonb_array_2_bigint_array: Final[str] = 'jsonb_array_2_bigint_array'
    jsonb_array_2_int_array: Final[str] = 'jsonb_array_2_int_array'
    jsonb_2_jsonb_array: Final[str] = 'jsonb_2_jsonb_array'
    jsonb_array_2_smallint_array: Final[str] = 'jsonb_array_2_smallint_array'
    jsonb_array_2_text_array: Final[str] = 'jsonb_array_2_text_array'
    jsonb_array_2_uuid_array: Final[str] = 'jsonb_array_2_uuid_array'
    jsonb_remove_key: Final[str] = 'jsonb_remove_key'

    jsonb_id_array_2_bigint_array: Final[str] = 'jsonb_id_array_2_bigint_array'
    jsonb_id_array_2_int_array: Final[str] = 'jsonb_id_array_2_int_array'
